Function caesar_core::relay::server::download_success
source · pub async fn download_success(
__arg0: State<Arc<RwLock<AppState>>>,
__arg1: Path<String>
) -> impl IntoResponseExpand description
Delete a transfer request by its name.
Arguments
shared_state- The shared state containing the transfer requests.name- The name of the transfer request.
Returns
Returns a response containing a JSON object with a message indicating the success of the deletion. If the transfer request is not found, a not found response is returned.